************************************************************************
*
*  File: NUGETTC
*
*  Returns the TestCases for the given user and library.
*
*  Tags: NUNIT
*
*  Parameters:
*    NUGETTCP.USERNAME - The username.
*    NUGETTCP.LIBRARY  - The library.
*
*  Returns:
*    NUGETTCP.MESSAGE   - The error message (if any).
*    NUGETTCP.TESTCASES - The TestCases for the user and library.
*
*  About:
*    Library       - NUNIT
*    Erstellt      - 29.08.2009
*    Autor         - $Author: Stefan $
*    Revison       - $LastChangedRevision: 264 $
*    Letzter Autor - $LastChangedBy: Stefan $
*    Modifiziert   - $Date: 2009-08-31 12:44:42 +0200 (Mo, 31 Aug 2009) $
*    Id            - $Id: NUGETTC.NSS 264 2009-08-31 10:44:42Z Stefan $
************************************************************************
*
DEFINE DATA
*
PARAMETER USING NUGETTCP
*
LOCAL
01 #L (N8)
01 #TC (N8)
01 #LINE (A200)
01 #NUM-LINES (N8)

01 #LINES (A200/1:*)
*
01 #TESTCASE-QUALIFIED
  02 #TC-LIBRARY (A8) 
  02 #TC-WITH-COMMENT (A192) 
01 #TESTCASE (A8)
*
01 #INDEX-COMMENT (N3)
*
END-DEFINE
*
************************************************************************
DEFINE SUBROUTINE GET-TESTCASES
************************************************************************
*
* only read TestCase file if TestCases are not already set
#NUM-LINES := *OCCURRENCE(NUGETTCP.TESTCASES)
IF #NUM-LINES EQ 0
  PERFORM READ-TESTCASE-FILE NUGETTCP.USERNAME #LINES(*) NUGETTCP.MESSAGE 
ELSE
  RESIZE ARRAY #LINES TO (1:#NUM-LINES) 
  MOVE NUGETTCP.TESTCASES(*) TO #LINES(*) 
  REDUCE ARRAY NUGETTCP.TESTCASES TO 0 
END-IF
*
FOR #L 1 *OCCURRENCE(#LINES)
*
  #LINE := *TRIM(#LINES(#L)) 
  IF #LINE EQ ' ' 
    ESCAPE TOP 
  END-IF 
*
* comments start with #, TestSuites start with [
  IF SUBSTRING(#LINE, 1, 1) EQ '#' OR 
      SUBSTRING(#LINE, 1, 1) EQ '[' 
    ESCAPE TOP 
  END-IF 
*
  SEPARATE #LINE INTO #TESTCASE-QUALIFIED WITH DELIMITER '.' 
  EXAMINE #TC-LIBRARY TRANSLATE INTO UPPER CASE 
*
  IF #TC-LIBRARY EQ NUGETTCP.LIBRARY 
    COMPRESS #TC-WITH-COMMENT INTO #TESTCASE 
*
*   handle inline comments starting with #
    EXAMINE #TESTCASE FOR '#' GIVING POSITION IN #INDEX-COMMENT 
    IF #INDEX-COMMENT NE 0 
      SUBTRACT 1 FROM #INDEX-COMMENT 
      #TESTCASE := SUBSTRING(#TESTCASE, 1, #INDEX-COMMENT) 
    END-IF 
*
    #TESTCASE := *TRIM(#TESTCASE) 
    IF #TESTCASE EQ ' ' 
      ESCAPE TOP 
    END-IF 
    EXAMINE #TESTCASE TRANSLATE INTO UPPER CASE 
*
    ADD 1 TO #TC 
    RESIZE ARRAY NUGETTCP.TESTCASES TO (1:#TC) 
    NUGETTCP.TESTCASES(#TC) := #TESTCASE 
  END-IF 
*
END-FOR
*
ON ERROR
  IF *ERROR-NR EQ 1314 /* Target field too small for field portion 
    COMPRESS NUMERIC 'Invalid TestCase: <' #LINE '> in line' #L 
      INTO NUGETTCP.MESSAGE 
    REDUCE ARRAY NUGETTCP.TESTCASES TO 0 
    ESCAPE MODULE 
  END-IF 
END-ERROR
END-SUBROUTINE
*
END
